// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk;

/**
 * Interface for call routing algorithms.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.1
 */

public interface CallRouter {

    /**
     * Interface for GnuGk callrouting algorithms.
     * The algorithm is passed all data provided by GnuGk and will choose whatever
     * it wants to use.
     * @param queue         H.323 alias that was called
     * @param callerEndId   endpoint ID of the caller
     * @param callRef       call Refernce
     * @param callerAlias   callers H.323 alias
     * @param callerIp      callerrs IP number
     * @return              endpoint where to route the call
     */
    public Alias routeCall(String queue, String callerEndId,
                              String callRef, String callerAlias, String callerIp);

    /**
     * Add endpoint.
     * @param _alias    H.323 alias
     * @param _epid     endpoint ID
     */
    public void addAlias(String _alias, String _epid);

    /**
     * Remove all aliases for this endpoint ID.
     * @param _epid     endpoint ID
     */
    public void removeAllAliases(String _epid);

    /**
     * Set _all_ aliases on this endpoint with this CRV to available
     * @param _epid endpoint ID
     * @param _crv  CRV
     */
    public void setAliasAvailable(String _epid, String _crv);

    /**
     * Set this alias on this endpoint to TALKING and remember the CRV
     * @param _alias    H.323 alias
     * @param _crv      CRV
     */
    public void setAliasTalking(String _alias, String _crv);

    void clearAllAliasStates();

}
