// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

import org.gnugk.Logger;

import java.net.Socket;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * Thread to handle one client that send commands to the ACD.
 * Uses HTTP protocol, so you can point your browser at it.
 * Example: http://localhost:7001/logout?frank
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
public class ACDCommandListenerThread implements Runnable {
    private Socket socket;
    private String location;

    /**
     * Initialize the worker thread.
     * @param socket    connection to handle
     * @param redirLocation where to redirect after command
     */
    public ACDCommandListenerThread(Socket socket, String redirLocation) {
        this.socket = socket;
        this.location = redirLocation;
    }

    public void run() {
        GnuGkACD acd = GnuGkACD.getInstance();

        try {
            BufferedReader in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            PrintWriter out = new PrintWriter(socket.getOutputStream(), true);
            String inputLine;
            boolean done = false;
            while ((!done && (inputLine = in.readLine()) != null)) {
                Logger.debug("HTTP:" + inputLine);
                // handle commands
                if (inputLine.startsWith("GET /logout") || inputLine.startsWith("GET /logoff") ) {
                    done = true;
                    String agent = inputLine.substring(12);
                    if (agent.indexOf(" ") > 0) {
                        agent = agent.substring(0, agent.indexOf(" "));
                    }
                    Logger.debug("Command accepted: Logout " + agent);
                    acd.logout(agent);
                    out.println ("HTTP/1.0 302 Moved Temporarily\nLocation: " + location + "\n\n");
                }
                if (inputLine.startsWith("GET /login")) {
                    done = true;
                    String agent = inputLine.substring(11);
                    if (agent.indexOf(" ") > 0) {
                        agent = agent.substring(0, agent.indexOf(" "));
                    }
                    Logger.debug("Command accepted: Login " + agent);
                    acd.login(agent);
                    out.println ("HTTP/1.0 302 Moved Temporarily\nLocation: " + location + "\n\n");
                }
                if (inputLine.startsWith("GET /status")) {
                    done = true;
                    Logger.debug("Command accepted: Status");
                    out.println ("HTTP/1.0 200 OK\nContent-Type: text/plain\n\n" + acd.dumpAgentStates());
                }
            }
            // out.print("HTTP/1.0 200 OK\nContent-Type: text/html\nContent-Length: 0\n\n");
            out.close();
            in.close();
            socket.close();
        } catch (IOException ioe) {
            // ignore
        }
    }
}
