// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

import org.gnugk.GnuGkAppConfig;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * AgentConfig is a Singleton class to deal with the ACD configuration.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */

public class ACDConfig extends GnuGkAppConfig {
    private static ACDConfig instance = new ACDConfig();
    private ResourceBundle agentConfig;

    // constants for distribution algorithms
    public final static int FIRST_FIT = 1;
    public final static int ROUND_ROBIN = 2;
    public final static int LONGEST_IDLE = 3;

    /**
     * Singleton access method.
     * @return the object
     */
    public static ACDConfig getInstance() {
        return instance;
    }

    /**
     * constructor must be private to ensure Singleton property.
     */
    private ACDConfig() {
        // load config file
        readConfig("ACDConfig");
        try {
            agentConfig = ResourceBundle.getBundle("ACDAgentConfig");
        } catch (MissingResourceException e) {
            System.out.println("Can find config file: Place ACDAgentConfig.properties on CLASSPATH !");
            System.exit(-1);
        }
    }

    /**
     * Distribution algorithem the lected in config file.
     * @return constant for algorithm
     */
    public int getDistributionAlgorithm() {
        String algo = getConfigKey("distribution_algorithm", "FIRST_FIT");
        if (algo.equals("ROUND_ROBIN"))
            return ROUND_ROBIN;
        else if (algo.equals("LONGEST_IDLE"))
            return LONGEST_IDLE;
        else
            return FIRST_FIT;
    }

    /**
     * Get the Agent configuration.
     * @return  the resource bundle
     */
    public ResourceBundle getAgentConfig() {
        return agentConfig;
    }

}
